#basic commands for people who dgaf about python
def add(a, b):
    return a + b
def mult(a, b): 
    return a * b
def sub(a, b): 
    return a - b 
def div(a, b): 
    return a / b 
def exp(a, power): 
    return a**power

    
       
    